.. highlight:: shell

Installation
============

Stable release
--------------

Requires Python 3.5+.

.. code-block:: console

    $ pip install pypenelopetools
    
Development
-----------

Clone the Github repository, either directly or after forking:

.. code-block:: console

    $ git clone https://github.com/pymontecarlo/pypenelopetools.git

Install the project in editable mode:

.. code-block:: console

    $ cd pypenelopetools
    $ pip install -e .

Run the unit tests to make sure everything works properly:

.. code-block:: console

    $ python setup.py nosetests